from oarepo_ui.resources.config import TemplatePageUIResourceConfig
from oarepo_ui.resources.resource import TemplatePageUIResource


class ComponentsResourceConfig(TemplatePageUIResourceConfig):
    url_prefix = "/"
    blueprint_name = "nr_components"
    template_folder = "templates"


def create_blueprint(app):
    """Register blueprint for this resource."""
    return TemplatePageUIResource(ComponentsResourceConfig()).as_blueprint()



from flask import current_app
from werkzeug.local import LocalProxy


def _ext_proxy(attr):
    return LocalProxy(
        lambda: getattr(current_app.extensions["nr_metadata.documents"], attr)
    )


current_service = _ext_proxy("service_records")
"""Proxy to the instantiated service."""


current_resource = _ext_proxy("resource_records")
"""Proxy to the instantiated resource."""



from invenio_drafts_resources.resources import RecordResource


class CommonResource(RecordResource):
    """CommonRecord resource."""

    # here you can for example redefine
    # create_url_rules function to add your own rules



from nr_metadata.documents.records.api import DocumentsRecord
from nr_metadata.documents.resources.records.config import DocumentsResourceConfig
from nr_metadata.documents.resources.records.resource import DocumentsResource
from nr_metadata.documents.services.records.config import DocumentsServiceConfig
from nr_metadata.documents.services.records.service import DocumentsService

DOCUMENTS_RECORD_RESOURCE_CONFIG = DocumentsResourceConfig


DOCUMENTS_RECORD_RESOURCE_CLASS = DocumentsResource


DOCUMENTS_RECORD_SERVICE_CONFIG = DocumentsServiceConfig


DOCUMENTS_RECORD_SERVICE_CLASS = DocumentsService


OAREPO_PRIMARY_RECORD_SERVICE = {DocumentsRecord: "documents"}



from oarepo_runtime.records.dumpers.edtf_interval import EDTFIntervalDumperExt


class DataEDTFIntervalDumperExt(EDTFIntervalDumperExt):
    """edtf interval dumper."""

    paths = [
        "metadata/dateCollected",
        "metadata/dateCreated",
        "metadata/events/eventDate",
    ]



from nr_metadata.data.records.api import DataRecord
from nr_metadata.data.resources.records.config import DataResourceConfig
from nr_metadata.data.resources.records.resource import DataResource
from nr_metadata.data.services.records.config import DataServiceConfig
from nr_metadata.data.services.records.service import DataService

DATA_RECORD_RESOURCE_CONFIG = DataResourceConfig


DATA_RECORD_RESOURCE_CLASS = DataResource


DATA_RECORD_SERVICE_CONFIG = DataServiceConfig


DATA_RECORD_SERVICE_CLASS = DataService


OAREPO_PRIMARY_RECORD_SERVICE = {DataRecord: "data"}
